@@ -129,6 +129,16 @@ stfio::filetype stfio::importBiosigFile(const std::string &fName, Recording &Ret
         return type;
     }
 
+    // earlier versions of biosig support only the file type identification, but did not read AXG files
+    if ( (BIOSIG_VERSION < 10600)
+      && (biosig_filetype==AXG)
+       ) {
+        // biosig's AXG import crashes on Windows at this time
+        ReturnData.resize(0);
+        destructHDR(hdr);
+        return type;
+    }
+
     // ensure the event table is in chronological order	
     sort_eventtable(hdr);
 
@@ -340,6 +350,18 @@ stfio::filetype stfio::importBiosigFile(const std::string &fName, Recording &Ret
         return type;
     }
 
+    // earlier versions of biosig support only the file type identification, but did not read AXG files
+#if defined(BIOSIG_VERSION) && (BIOSIG_VERSION > 10403)
+    if ( (BIOSIG_VERSION < 10600)
+         && (hdr->TYPE==AXG)
+       ) {
+        // biosig's AXG import crashes on Windows at this time
+        ReturnData.resize(0);
+        destructHDR(hdr);
+        return type;
+    }
+#endif
+    
     // ensure the event table is in chronological order
     sort_eventtable(hdr);
 
@@ -782,7 +804,14 @@ bool stfio::exportBiosigFile(const std::string& fName, const Recording& Data, st
 
 	/* Initialize all header parameters */
     hdr->TYPE = GDF;
-    hdr->VERSION = 3.0;   // latest version
+#if (BIOSIG_VERSION >= 10508)
+    /* transition in biosig to rename HDR->VERSION to HDR->Version
+       to avoid name space conflict with macro VERSION
+     */
+    hdr->Version = 3.0;   // select latest supported version of GDF format
+#else
+    hdr->VERSION = 3.0;   // select latest supported version of GDF format
+#endif
 
     struct tm t = Data.GetDateTime();
 
