@@ -9,6 +9,8 @@
 #include "./../doc.h"
 
 enum {
+    wxLOADCRS,
+    wxSAVECRS,
     wxCOMBOUM,
     wxCOMBOU1P,
     wxCOMBOU2P,
@@ -39,6 +41,7 @@ enum {
     wxTEXTPM,
     wxRADIOALL,
     wxRADIOMEAN,
+    wxRADIO_BASELINE_METHOD,	// 0: mean + s.d.;  1: median + iqr
     wxRADIO_LAT_MAXSLOPE1,
     wxRADIO_LAT_HALFWIDTH1,
     wxRADIO_LAT_PEAK1,
@@ -70,7 +73,7 @@ enum {
     wxSLOPEUNITS,
     wxREFERENCE,
     wxSTARTFITATPEAK,
-    wxID_STARTFITATPEAK,
+    //wxID_STARTFITATPEAK,
     wxRT_LABEL,
     wxRT_SLIDER,
     wxIDNOTEBOOK
@@ -93,8 +96,10 @@ EVT_COMBOBOX( wxCOMBOU1PS, wxStfCursorsDlg::OnComboBoxU1PS )
 EVT_COMBOBOX( wxCOMBOU2PS, wxStfCursorsDlg::OnComboBoxU2PS )
 #endif
 
-// bindings radio buttons
 EVT_BUTTON( wxID_APPLY, wxStfCursorsDlg::OnPeakcalcexec )
+EVT_BUTTON( wxID_OPEN, wxStfCursorsDlg::OnLoadCursorConf )
+EVT_BUTTON( wxID_SAVE, wxStfCursorsDlg::OnSaveCursorConf )
+// bindings radio buttons
 EVT_RADIOBUTTON( wxRADIOALL, wxStfCursorsDlg::OnRadioAll )
 EVT_RADIOBUTTON( wxRADIOMEAN, wxStfCursorsDlg::OnRadioMean )
 
@@ -110,6 +115,8 @@ EVT_RADIOBUTTON( wxRADIO_LAT_MAXSLOPE2,  wxStfCursorsDlg::OnRadioLatNonManualEnd
 EVT_RADIOBUTTON( wxRADIO_LAT_EVENT2,     wxStfCursorsDlg::OnRadioLatNonManualEnd )
 
 EVT_COMMAND_SCROLL( wxRT_SLIDER,        wxStfCursorsDlg::OnRTSlider )
+EVT_CHECKBOX (wxPEAKATEND, wxStfCursorsDlg::OnPeakAtEnd )
+EVT_CHECKBOX (wxSTARTFITATPEAK, wxStfCursorsDlg::OnStartFitAtPeak )
 #ifdef WITH_PSLOPE
 EVT_RADIOBUTTON( wxRADIO_PSManBeg, wxStfCursorsDlg::OnRadioPSManBeg )
 EVT_RADIOBUTTON( wxRADIO_PSEventBeg, wxStfCursorsDlg::OnRadioPSEventBeg )
@@ -148,12 +155,18 @@ wxStfCursorsDlg::wxStfCursorsDlg(wxWindow* parent, wxStfDoc* initDoc, int id, wx
 #endif
     topSizer->Add( m_notebook, 1, wxEXPAND | wxALL, 5 );
 
-    wxStdDialogButtonSizer* pSdbSizer = new wxStdDialogButtonSizer();
-    //pSdbSizer->AddButton( new wxButton( this, wxID_OK ) );
-    //pSdbSizer->AddButton( new wxButton( this, wxID_CANCEL ) );
-    pSdbSizer->AddButton( new wxButton( this, wxID_CANCEL, wxT("Close") ) );
-    pSdbSizer->AddButton( new wxButton( this, wxID_APPLY ) );
-    pSdbSizer->Realize();
+    wxButton* bClose = new wxButton( this, wxID_CANCEL, wxT("Close") );
+    wxButton* bApply = new wxButton( this, wxID_APPLY, wxT("Apply") );
+    wxButton* bLoad = new wxButton( this, wxID_OPEN, wxT("Load") );
+    wxButton* bSave = new wxButton( this, wxID_SAVE, wxT("Save") );
+
+    wxBoxSizer* pSdbSizer = new wxBoxSizer(wxHORIZONTAL);
+    pSdbSizer->Add( bClose, 0, wxALL, 1); 
+    pSdbSizer->Add( bApply, 0, wxALL, 1); 
+    pSdbSizer->Add( bLoad, 0, wxALL, 1); 
+    pSdbSizer->Add( bSave, 0, wxALL, 1); 
+    //pSdbSizer->Realize();
+
     topSizer->Add( pSdbSizer, 0, wxALIGN_CENTER | wxALL, 5 );
     topSizer->SetSizeHints(this);
     this->SetSizer( topSizer );
@@ -194,6 +207,32 @@ void wxStfCursorsDlg::EndModal(int retCode) {
     wxDialog::EndModal(retCode);
 }
 
+bool wxStfCursorsDlg::IsCSRSyntax( wxFileConfig* csr_file) {
+    
+    wxString msg = wxT("Syntax Error: ");
+
+    // Check groups
+    wxString CSR_Group[] = { wxT("__CSR_HEADER__"), wxT("__MEASURE__"), wxT("__PEAK__"),
+        wxT("__BASE__"), wxT("__DECAY__"), wxT("__LATENCY__") };
+    unsigned int nGroups = sizeof(CSR_Group)/sizeof(wxString);
+
+    for (std::vector<int>::size_type i=0; i<nGroups; i++) {
+        if (! csr_file->HasGroup(CSR_Group[i])) {
+            wxGetApp().ErrorMsg( msg + CSR_Group[i] + wxT(" not found !") );
+            return false;
+        }
+    }
+    // check entry in every group
+    
+    
+    // Other checkings... number of Groups
+    if (nGroups != csr_file->GetNumberOfGroups()) {
+        wxGetApp().ErrorMsg( wxT("Unexpected number of groups") );
+        return false;
+    }
+    return true;
+}
+
 bool wxStfCursorsDlg::OnOK() {
     //wxCommandEvent unusedEvent;
     //OnPeakcalcexec(unusedEvent);
@@ -208,7 +247,7 @@ wxNotebookPage* wxStfCursorsDlg::CreateMeasurePage() {
     pageSizer->Add( CreateCursorInput( nbPage, wxTEXTM, -1, wxCOMBOUM,
             -1, 1, 10 ), 0, wxALIGN_CENTER | wxALL, 2 );
     wxCheckBox* pMeasCursor=new wxCheckBox( nbPage, wxMEASCURSOR,
-            wxT("Vertical ruler through cursor"), wxDefaultPosition,
+            wxT("Show vertical ruler through cursor"), wxDefaultPosition,
             wxDefaultSize, 0 );
     pageSizer->Add( pMeasCursor, 0, wxALIGN_CENTER | wxALL, 2);
 
@@ -360,6 +399,22 @@ wxNotebookPage* wxStfCursorsDlg::CreateBasePage() {
     pageSizer->Add( CreateCursorInput( nbPage, wxTEXT1B, wxTEXT2B, wxCOMBOU1B,
             wxCOMBOU2B, 1, 10 ), 0, wxALIGN_CENTER | wxALL, 2 );
 
+    // Grid
+    wxFlexGridSizer* BaseMethodSizer = new wxFlexGridSizer(1, 0, 0);
+    wxString BaselineMethods[] = {
+        wxT("Mean and Standard Deviation (SD)"),
+        wxT("Median and InterQuartil Ratio (IQR)")
+    };
+    int iBaselineMethods = sizeof(BaselineMethods) / sizeof(wxString);
+    //**** Radio options for baseline methods "mean, or median " ****
+    wxRadioBox* pBaselineMethod = new wxRadioBox( nbPage, wxRADIO_BASELINE_METHOD,
+        wxT("Method to compute the baseline"), wxDefaultPosition, wxDefaultSize, 
+        iBaselineMethods, BaselineMethods, 0, wxRA_SPECIFY_ROWS );    
+    pBaselineMethod->SetSelection(0);
+
+    BaseMethodSizer->Add(pBaselineMethod, 0, wxALIGN_CENTER | wxALIGN_TOP | wxALL, 2);
+    pageSizer->Add( BaseMethodSizer, 0, wxALIGN_CENTER | wxALL, 2 );
+
     pageSizer->SetSizeHints(nbPage);
     nbPage->SetSizer( pageSizer );
     nbPage->Layout();
@@ -415,7 +470,6 @@ wxNotebookPage* wxStfCursorsDlg:: CreateLatencyPage(){
     // Latency from: Manual
     wxRadioButton* wxRadio_Lat_Manual1 = new wxRadioButton( nbPage, wxRADIO_LAT_MANUAL1, wxT("Manual"),
             wxDefaultPosition, wxDefaultSize, wxRB_GROUP);
-    //wxRadio_Lat_Manual1->SetValue(true);
     
     // Latency from: Peak
     wxRadioButton* wxRadio_Lat_Peak1 = new wxRadioButton( nbPage, wxRADIO_LAT_PEAK1, wxT("Peak"),
@@ -507,8 +561,8 @@ wxNotebookPage* wxStfCursorsDlg::CreatePSlopePage() {
             wxDefaultPosition, wxDefaultSize, wxRB_GROUP );
     //pPSManBeg->SetValue(true);
 
-    // Slope from: Commencement
-    wxRadioButton* pPSEventBeg = new wxRadioButton( nbPage, wxRADIO_PSEventBeg, wxT("Commencement"),
+    // Slope from: Beginning of event 
+    wxRadioButton* pPSEventBeg = new wxRadioButton( nbPage, wxRADIO_PSEventBeg, wxT("Beginning of event"),
             wxDefaultPosition, wxDefaultSize );
      
     // Slope from: Threshold slope
@@ -695,6 +749,339 @@ void wxStfCursorsDlg::OnPeakcalcexec( wxCommandEvent& event )
     wxGetApp().OnPeakcalcexecMsg(actDoc);
 }
 
+bool wxStfCursorsDlg::LoadCursorConf(const wxString& filepath ){
+    
+    // When loading the configuration we'll write directly in the active document
+    // loading a cursor file will also update measurements, cursors, the graph and result table.
+    // It will write the registry as well, since it is similar to pressing "Apply".
+    // see wxStfApp::OnPeakcalcexeMsg() for details.
+    if (actDoc == NULL) {
+        wxGetApp().ErrorMsg(wxT("No active document found"));
+        return false;
+    }
+
+    wxFileConfig* csr_config = new wxFileConfig(wxT(""), wxT(""), filepath );
+
+    // minimal syntax check
+    if ( !IsCSRSyntax( csr_config ) ) {
+        return false;
+    }
+
+    wxString CursorValue;
+    long start_csr, end_csr;
+    // *** update controls in __MEASURE__ tab **** 
+    csr_config->Read( wxT("__MEASURE__/Cursor"), &start_csr ); // read from file
+
+    wxTextCtrl *pMeasureCursor = (wxTextCtrl*)FindWindow(wxTEXTM);
+    if (pMeasureCursor == NULL) {
+        wxGetApp().ErrorMsg(wxT("null pointer in wxStfCursorsDlg::LoadCursorConf()"));
+        return false;
+    }
+    if (cursorMIsTime) {
+        float fvalue =  start_csr*actDoc->GetXScale() ;
+        CursorValue = wxString::Format( wxT("%f"), fvalue );    
+    }
+    else
+        CursorValue = wxString::Format( wxT("%i"), start_csr );
+    
+    pMeasureCursor->SetValue( CursorValue );
+    actDoc->SetMeasCursor( GetCursorM() );
+
+    int show_ruler;
+    csr_config->Read( wxT("__MEASURE__/ShowRuler"), &show_ruler ); // read from file
+    SetRuler( show_ruler ); 
+    actDoc->SetMeasRuler( show_ruler );
+
+    // **** update controls in __PEAK__ tab ****
+    csr_config->Read( wxT("__PEAK__/LeftCursor"), &start_csr ); // read from file
+    csr_config->Read( wxT("__PEAK__/RightCursor"), &end_csr ); // read from file
+
+    wxTextCtrl *pPeak1Cursor = (wxTextCtrl*)FindWindow(wxTEXT1P);
+    wxTextCtrl *pPeak2Cursor = (wxTextCtrl*)FindWindow(wxTEXT2P);
+    if (pPeak1Cursor == NULL || pPeak2Cursor == NULL) {
+        wxGetApp().ErrorMsg(wxT("null pointer in wxStfCursorsDlg::LoadCursorConf()"));
+        return false;
+    }
+    if (cursor1PIsTime) {
+        float fvalue =  start_csr*actDoc->GetXScale() ;
+        CursorValue = wxString::Format( wxT("%f"), fvalue );    
+    }
+    else
+        CursorValue = wxString::Format( wxT("%i"), start_csr );
+
+    pPeak1Cursor->SetValue( CursorValue );
+    actDoc->SetPeakBeg( GetCursor1P() );
+
+    if (cursor2PIsTime) {
+        float fvalue =  end_csr*actDoc->GetXScale() ;
+        CursorValue = wxString::Format( wxT("%f"), fvalue );    
+    }
+    else
+        CursorValue = wxString::Format( wxT("%i"), end_csr );
+
+    pPeak2Cursor->SetValue( CursorValue );
+    actDoc->SetPeakEnd( GetCursor2P() );
+
+    bool is_end;
+    csr_config->Read( wxT("__PEAK__/PeakAtEnd"), &is_end ); // read from file
+    SetPeakAtEnd( is_end ); 
+    actDoc->SetPeakAtEnd( is_end );
+    
+    int npoints; 
+    csr_config->Read( wxT("__PEAK__/NumberOfPoints"), &npoints ); // read from file
+    SetPeakPoints( npoints); 
+    actDoc->SetPM( npoints );
+
+    int direction;
+    csr_config->Read( wxT("__PEAK__/Direction"), &direction ); // read from file
+    stf::direction mydirection;
+    switch (direction) {
+        case 0: mydirection = stf::up; break;
+        case 1: mydirection = stf::down; break;
+        case 2: mydirection = stf::both; break;
+        default: mydirection = stf::undefined_direction;
+    }
+    SetDirection( mydirection ); 
+    actDoc->SetDirection ( mydirection );
+
+    bool confbase;
+    csr_config->Read( wxT("__PEAK__/FromBase"), &confbase ); // read from file
+    SetFromBase( confbase ); 
+    actDoc->SetFromBase( confbase );
+
+    int rt_factor;
+    csr_config->Read( wxT("__PEAK__/RTFactor"), &rt_factor ); // read from file
+    SetRTFactor( rt_factor );
+    actDoc->SetRTFactor( rt_factor );
+
+    double slope;
+    wxString wxSlope; 
+    csr_config->Read( wxT("__PEAK__/Slope"), &wxSlope); // read from file
+    wxSlope.ToDouble(&slope);
+    SetSlope( slope );
+    actDoc->SetSlopeForThreshold( slope );
+
+    // **** update controls in __BASE__ tab ****
+    csr_config->Read( wxT("__BASE__/LeftCursor"), &start_csr ); // read from file
+    csr_config->Read( wxT("__BASE__/RightCursor"), &end_csr ); // read from file
+    wxTextCtrl *pBase1Cursor = (wxTextCtrl*)FindWindow(wxTEXT1B);
+    wxTextCtrl *pBase2Cursor = (wxTextCtrl*)FindWindow(wxTEXT2B);
+    if (pBase1Cursor == NULL || pBase2Cursor == NULL) {
+        wxGetApp().ErrorMsg(wxT("null pointer in wxStfCursorsDlg::LoadCursorConf()"));
+        return false;
+    }
+    if (cursor1BIsTime) {
+        float fvalue =  start_csr*actDoc->GetXScale() ;
+        CursorValue = wxString::Format( wxT("%f"), fvalue );    
+    }
+    else
+        CursorValue = wxString::Format( wxT("%i"), start_csr );
+
+    pBase1Cursor->SetValue( CursorValue );
+    actDoc->SetBaseBeg( GetCursor1B() );
+
+    if (cursor2BIsTime) {
+        float fvalue =  end_csr*actDoc->GetXScale() ;
+        CursorValue = wxString::Format( wxT("%f"), fvalue );    
+    }
+    else
+        CursorValue = wxString::Format( wxT("%i"), end_csr );
+
+    pBase2Cursor->SetValue( CursorValue );
+    actDoc->SetBaseEnd( GetCursor2B() );
+
+    int base_method; 
+    csr_config->Read( wxT("__BASE__/BaselineMethod"), &base_method ); // read from file
+    stf::baseline_method mybase_method;
+    switch( base_method ) {
+        case 0: mybase_method = stf::mean_sd; break;
+        case 1: mybase_method = stf::median_iqr; break;
+        default: mybase_method = stf::mean_sd;
+    }
+    SetBaselineMethod ( mybase_method );
+    actDoc->SetBaselineMethod( mybase_method );
+
+    // **** update controls in __DECAY__ tab ****
+    csr_config->Read( wxT("__DECAY__/LeftCursor"), &start_csr ); // read from file
+    csr_config->Read( wxT("__DECAY__/RightCursor"), &end_csr ); // read from file
+    wxTextCtrl *pFit1Cursor = (wxTextCtrl*)FindWindow(wxTEXT1D);
+    wxTextCtrl *pFit2Cursor = (wxTextCtrl*)FindWindow(wxTEXT2D);
+    if (pBase1Cursor == NULL || pBase2Cursor == NULL) {
+        wxGetApp().ErrorMsg(wxT("null pointer in wxStfCursorsDlg::LoadCursorConf()"));
+        return false;
+    }
+    if (cursor1DIsTime) {
+        float fvalue =  start_csr*actDoc->GetXScale() ;
+        CursorValue = wxString::Format( wxT("%f"), fvalue );    
+    }
+    else
+        CursorValue = wxString::Format( wxT("%i"), start_csr );
+
+    pFit1Cursor->SetValue( CursorValue );
+    actDoc->SetFitBeg( GetCursor1D() );
+
+    if (cursor2DIsTime) {
+        float fvalue =  end_csr*actDoc->GetXScale() ;
+        CursorValue = wxString::Format( wxT("%f"), fvalue );    
+    }
+    else
+        CursorValue = wxString::Format( wxT("%i"), end_csr );
+
+    pFit2Cursor->SetValue( CursorValue );
+    actDoc->SetFitEnd( GetCursor2D() );
+
+    bool is_peak;
+    csr_config->Read(wxT("__DECAY__/StartFitAtPeak"), &is_peak);
+    SetStartFitAtPeak( is_peak); 
+    actDoc->SetStartFitAtPeak( is_peak );
+    
+
+
+    // **** update controls in LATENCY tab ****
+    csr_config->Read( wxT("__LATENCY__/LeftCursor"), &start_csr ); // read from file
+    csr_config->Read( wxT("__LATENCY__/RightCursor"), &end_csr ); // read from file
+    wxTextCtrl *pLatency1Cursor = (wxTextCtrl*)FindWindow(wxTEXT1L);
+    wxTextCtrl *pLatency2Cursor = (wxTextCtrl*)FindWindow(wxTEXT2L);
+    if (pLatency1Cursor == NULL || pLatency2Cursor == NULL) {
+        wxGetApp().ErrorMsg(wxT("null pointer in wxStfCursorsDlg::LoadCursorConf()"));
+        return false;
+    }
+    if (cursor1LIsTime) {
+        float fvalue =  start_csr*actDoc->GetXScale() ;
+        CursorValue = wxString::Format( wxT("%f"), fvalue );    
+    }
+    else
+        CursorValue = wxString::Format( wxT("%i"), start_csr );
+
+    pLatency1Cursor->SetValue( CursorValue );
+    actDoc->SetLatencyBeg( GetCursor1L() );
+
+    if (cursor2LIsTime) {
+        float fvalue =  end_csr*actDoc->GetXScale() ;
+        CursorValue = wxString::Format( wxT("%f"), fvalue );    
+    }
+    else
+        CursorValue = wxString::Format( wxT("%i"), end_csr );
+
+    pLatency2Cursor->SetValue( CursorValue );
+    actDoc->SetLatencyEnd( GetCursor2L() );
+
+    int mode;
+    csr_config->Read( wxT("__LATENCY__/LeftMode"), &mode ); // read from file
+    stf::latency_mode latency_mode;
+    switch( mode ) {
+        case 0: latency_mode =stf::manualMode; break;
+        case 1: latency_mode = stf::peakMode; break;
+        case 2: latency_mode = stf::riseMode; break;
+        case 3: latency_mode = stf::halfMode; break;
+        case 4: latency_mode = stf::footMode; break;
+        default: latency_mode = stf::undefinedMode;
+    } 
+    SetLatencyStartMode( latency_mode );
+    actDoc->SetLatencyStartMode( latency_mode );
+
+    csr_config->Read( wxT("__LATENCY__/RightMode"), &mode ); // read from file
+    switch( mode ) {
+        case 0: latency_mode =stf::manualMode; break;
+        case 1: latency_mode = stf::peakMode; break;
+        case 2: latency_mode = stf::riseMode; break;
+        case 3: latency_mode = stf::halfMode; break;
+        case 4: latency_mode = stf::footMode; break;
+        default: latency_mode = stf::undefinedMode;
+    } 
+    SetLatencyEndMode( latency_mode );
+    actDoc->SetLatencyEndMode( latency_mode );
+
+    delete csr_config;
+    // we use wxStfApp::OnPeakcalcexec() here basically to update the results table.
+    // Because wxStfApp::OnPeakcalcexec() only updates the properties of wxStfDoc in the current tab 
+    // of the cursor dialog, we need to call the methods from actDoc() to update the cursors which
+    // are not currently visible, but stored in the csr file.
+    wxGetApp().OnPeakcalcexecMsg(actDoc);
+    return true;
+}
+
+void wxStfCursorsDlg::OnLoadCursorConf( wxCommandEvent& event ) {
+    event.Skip();
+    wxString csrFilter = wxT("Cursor conf (*.csr)|*csr");
+
+    wxFileDialog*  LoadCursorDialog = new wxFileDialog(this, wxT("Load Cursor configuration"), 
+        wxT(""), wxT(""), csrFilter, wxFD_OPEN | wxFD_PREVIEW);
+    
+    if (LoadCursorDialog->ShowModal() == wxID_OK ){
+        wxString mypath = LoadCursorDialog->GetPath();
+        LoadCursorConf( mypath );
+        }
+}
+
+bool wxStfCursorsDlg::SaveCursorConf(const wxString& mypath ){
+    
+    // Read cursor configuration from active document!
+    if (actDoc == NULL){
+        throw std::runtime_error("No active document found");
+        return false;
+    }
+    
+    wxDateTime now = wxDateTime::Now();
+
+    wxFileConfig* csr_config = new wxFileConfig(wxT(""), wxT(""), mypath );
+    
+    csr_config->SetPath( wxT("__CSR_HEADER__") );
+    //csr_config->Write( wxT("Date"), now.Format( wxT("%Y/%M/%d"), wxDateTime::CET) );
+    csr_config->Write( wxT("Date"), now.Format( wxT("%A, %d %B, %Y"), wxDateTime::CET) );
+    csr_config->Write( wxT("Time"), now.Format( wxT("%H:%M:%S %p"), wxDateTime::CET) );
+
+    csr_config->SetPath( wxT("../__MEASURE__") );
+    csr_config->Write( wxT("Cursor"), (int)actDoc->GetMeasCursor() );
+    csr_config->Write( wxT("ShowRuler"), (int)actDoc->GetMeasRuler() );
+
+    csr_config->SetPath( wxT("../__PEAK__") );
+    csr_config->Write( wxT("LeftCursor"), (int)actDoc->GetPeakBeg() );
+    csr_config->Write( wxT("Rightcursor"), (int)actDoc->GetPeakEnd() );
+    csr_config->Write( wxT("PeakAtEnd"), (int)actDoc->GetPeakAtEnd() );
+    csr_config->Write( wxT("NumberOfPoints"), (int)actDoc->GetPM() );
+    csr_config->Write( wxT("Direction"), (int)actDoc->GetDirection() );
+    csr_config->Write( wxT("FromBase"), (int)actDoc->GetFromBase() );
+    csr_config->Write( wxT("RTFactor"), (int)actDoc->GetRTFactor() );
+    wxString mySlope; 
+    mySlope << actDoc->GetSlopeForThreshold();
+    csr_config->Write( wxT("Slope"), mySlope );
+
+    csr_config->SetPath( wxT("../__BASE__") );
+    csr_config->Write( wxT("LeftCursor"), (int)actDoc->GetBaseBeg() );
+    csr_config->Write( wxT("RightCursor"),(int)actDoc->GetBaseEnd() );
+    csr_config->Write( wxT("BaselineMethod"), (int)actDoc->GetBaselineMethod() );
+
+    csr_config->SetPath( wxT("../__DECAY__") );
+    csr_config->Write( wxT("LeftCursor"), (int)actDoc->GetFitBeg() );
+    csr_config->Write( wxT("RightCursor"),(int)actDoc->GetFitEnd() );
+    csr_config->Write( wxT("StartFitAtPeak"),(int)actDoc->GetStartFitAtPeak() );
+
+    csr_config->SetPath( wxT("../__LATENCY__") );
+    csr_config->Write( wxT("LeftCursor"), (int)actDoc->GetLatencyBeg() );
+    csr_config->Write( wxT("RightCursor"),(int)actDoc->GetLatencyEnd() );
+    csr_config->Write( wxT("LeftMode"),(int)actDoc->GetLatencyStartMode() );
+    csr_config->Write( wxT("RightMode"),(int)actDoc->GetLatencyEndMode() );
+
+    csr_config->Flush(); // write all changes
+    
+    return true;
+
+}
+
+void wxStfCursorsDlg::OnSaveCursorConf( wxCommandEvent& event ) {
+    event.Skip();
+    wxString crsFilter = wxT("Cursor conf (*.csr)|*csr");
+
+    wxFileDialog*  SaveCursorDialog = new wxFileDialog(this, wxT("Save Cursor configuration"), 
+        wxT(""), wxT(""), crsFilter, wxFD_SAVE | wxFD_PREVIEW);
+    
+    if (SaveCursorDialog->ShowModal() == wxID_OK ){
+        wxString mypath = SaveCursorDialog->GetPath();
+        SaveCursorConf( mypath ); 
+    }
+}
+
 int wxStfCursorsDlg::ReadCursor(wxWindowID textId, bool isTime) const {
     // always returns in units of sampling points,
     // conversion is necessary if it's in units of time:
@@ -718,6 +1105,28 @@ int wxStfCursorsDlg::ReadCursor(wxWindowID textId, bool isTime) const {
 
 }
 
+void wxStfCursorsDlg::WriteCursor(wxWindowID textId, bool isTime, long value) const {
+
+    wxString myvalue;
+
+    wxTextCtrl *pText = (wxTextCtrl*)FindWindow(textId);
+    if (pText == NULL) {
+        wxGetApp().ErrorMsg(wxT("null pointer in wxStfCursorsDlg::SetCursor()"));
+        return;
+    }
+
+    if (isTime){
+        float fvalue = stf::round( value/actDoc->GetXScale() );
+        myvalue = wxString::Format(wxT("%f"), fvalue);
+    }
+    else {
+        myvalue = wxString::Format(wxT("%i"), value);
+    }
+
+    pText->SetValue(myvalue);
+
+}
+
 #ifdef WITH_PSLOPE
 int wxStfCursorsDlg::ReadDeltaT(wxWindowID textID) const {
     // returns DeltaT entered in the textBox in units of sampling points
@@ -842,8 +1251,7 @@ void wxStfCursorsDlg::SetDeltaT (int DeltaT) {
 
 #endif // WITH_PSLOPE
 
-void wxStfCursorsDlg::SetPeakPoints(int peakPoints)
-{
+void wxStfCursorsDlg::SetPeakPoints(int peakPoints) {
     wxRadioButton* pRadioButtonAll = (wxRadioButton*)FindWindow(wxRADIOALL);
     wxRadioButton* pRadioButtonMean = (wxRadioButton*)FindWindow(wxRADIOMEAN);
     wxTextCtrl* pTextPM = (wxTextCtrl*)FindWindow(wxTEXTPM);
@@ -851,24 +1259,25 @@ void wxStfCursorsDlg::SetPeakPoints(int peakPoints)
         wxGetApp().ErrorMsg(wxT("null pointer in wxStfCursorsDlg::SetPeakPoints()"));
         return;
     }
-    if (peakPoints == -1) {
-        pRadioButtonAll->SetValue(true);
-        pRadioButtonMean->SetValue(false);
-        pTextPM->Enable(false);
-        return;
-    }
+
     if (peakPoints==0 || peakPoints<-1) {
         throw std::runtime_error("peak points out of range in wxStfCursorsDlg::SetPeakPoints()");
     }
-    wxString entry;
-    entry << peakPoints;
-    pRadioButtonAll->SetValue(false);
-    pRadioButtonMean->SetValue(true);
-    pTextPM->Enable();
-    pTextPM->SetValue( entry );
+    else if (peakPoints == -1) {
+        pRadioButtonAll->SetValue(true);
+        pRadioButtonMean->SetValue(false);
+        pTextPM->Enable(false);
+    }
+    else {
+        wxString entry;
+        entry << peakPoints;
+        pRadioButtonAll->SetValue(false);
+        pRadioButtonMean->SetValue(true);
+        pTextPM->Enable(true);
+        pTextPM->SetValue( entry );
+    }
 }
 
-
 stf::direction wxStfCursorsDlg::GetDirection() const {
     wxRadioBox* pDirection = (wxRadioBox*)FindWindow(wxDIRECTION);
     if (pDirection == NULL) {
@@ -881,6 +1290,8 @@ stf::direction wxStfCursorsDlg::GetDirection() const {
     case 2: return stf::both;
     default: return stf::undefined_direction;
     }
+
+
 }
 
 void wxStfCursorsDlg::SetDirection(stf::direction direction) {
@@ -944,6 +1355,37 @@ void wxStfCursorsDlg::SetFromBase(bool fromBase) {
     }
 }
 
+enum stf::baseline_method wxStfCursorsDlg::GetBaselineMethod() const {   
+    wxRadioBox* pBaselineMethod = (wxRadioBox*)FindWindow(wxRADIO_BASELINE_METHOD);
+    if (pBaselineMethod == NULL) {
+        wxGetApp().ErrorMsg(wxT("null pointer in wxStfCursorsDlg::GetBaseSelection()"));
+        return stf::mean_sd; //default value mean and standard deviation
+    }
+    
+    switch( pBaselineMethod->GetSelection() ) {
+        case 0: return stf::mean_sd;
+        case 1: return stf::median_iqr;
+        default: return stf::mean_sd;
+    }
+}
+
+void wxStfCursorsDlg::SetBaselineMethod(stf::baseline_method base_method) {
+    wxRadioBox* pBaselineMethod = (wxRadioBox*)FindWindow(wxRADIO_BASELINE_METHOD);
+    if (pBaselineMethod == NULL) {
+        wxGetApp().ErrorMsg(wxT("null pointer in wxStfCursorsDlg::SetBaselineMethod()"));
+        return;
+    } 
+
+    switch(base_method) {
+        case stf::median_iqr:
+            pBaselineMethod->SetSelection(1);
+            break;
+        case stf::mean_sd:
+            pBaselineMethod->SetSelection(0);
+            break;
+    }
+}
+
 bool wxStfCursorsDlg::GetPeakAtEnd() const
 {	//Check if 'Upper limit at end of trace' is selected
     wxCheckBox* pPeakAtEnd = (wxCheckBox*)FindWindow(wxPEAKATEND);
@@ -954,8 +1396,37 @@ bool wxStfCursorsDlg::GetPeakAtEnd() const
     return pPeakAtEnd->IsChecked();
 }
 
+void wxStfCursorsDlg::OnPeakAtEnd( wxCommandEvent& event) {
+    event.Skip();
+    wxCheckBox* pPeakAtEnd = (wxCheckBox*)FindWindow(wxPEAKATEND);
+    wxTextCtrl* pCursor2P = (wxTextCtrl*)FindWindow(wxTEXT2P);
+    
+    if (pPeakAtEnd == NULL || pCursor2P == NULL) {
+        wxGetApp().ErrorMsg(wxT("null pointer in wxStfCursorsDlg::OnPeakAtEnd()"));
+        return;
+    }
+    
+    // second peak cursor is inactive if the peak at the end checkbox is checked
+    pCursor2P->Enable(! pPeakAtEnd->IsChecked() ); 
+
+}
+    
+void wxStfCursorsDlg::SetPeakAtEnd( bool is_end ) {	
+    wxCheckBox* pPeakAtEnd = (wxCheckBox*)FindWindow(wxPEAKATEND);
+    wxTextCtrl* pCursor2P = (wxTextCtrl*)FindWindow(wxTEXT2P);
+
+    if (pPeakAtEnd == NULL || pCursor2P == NULL) {
+        wxGetApp().ErrorMsg(wxT("null pointer in wxStfCursorsDlg::SetPeakAtEnd()"));
+        return;
+    }
+        
+    pCursor2P->Enable( ! is_end );
+    pPeakAtEnd->SetValue( is_end );
+}
+
+
 bool wxStfCursorsDlg::GetStartFitAtPeak() const
-{   //Check if 'Upper limit at end of trace' is selected
+{   //Check if 'Start fit at peak' is selected
     wxCheckBox* pStartFitAtPeak = (wxCheckBox*)FindWindow(wxSTARTFITATPEAK);
     if (pStartFitAtPeak == NULL) {
         wxGetApp().ErrorMsg(wxT("null pointer in wxStfCursorsDlg::GetStartFitAtPeak()"));
@@ -964,6 +1435,35 @@ bool wxStfCursorsDlg::GetStartFitAtPeak() const
     return pStartFitAtPeak->IsChecked();
 }
 
+void wxStfCursorsDlg::SetStartFitAtPeak(bool is_peak){
+    wxCheckBox* pStartFitAtPeak = (wxCheckBox*)FindWindow(wxSTARTFITATPEAK);
+    wxTextCtrl* pCursor1D = (wxTextCtrl*)FindWindow(wxTEXT1D);
+
+    if (pStartFitAtPeak == NULL || pCursor1D == NULL) {
+        wxGetApp().ErrorMsg(wxT("null pointer in wxStfCursorsDlg::GetStartFitAtPeak()"));
+        return;
+    }
+
+    pCursor1D->Enable( ! is_peak );
+    pStartFitAtPeak->SetValue( is_peak);
+}
+
+void wxStfCursorsDlg::OnStartFitAtPeak( wxCommandEvent& event) {
+    event.Skip();
+    wxCheckBox* pStartFitAtPeak = (wxCheckBox*)FindWindow(wxSTARTFITATPEAK);
+    wxTextCtrl* pCursor1D = (wxTextCtrl*)FindWindow(wxTEXT1D);
+    
+    if (pStartFitAtPeak == NULL || pCursor1D == NULL) {
+        wxGetApp().ErrorMsg(wxT("null pointer in wxStfCursorsDlg::OnStartFitAtEnd()"));
+        return;
+    }
+    
+    // left decay cursor is inactive if the start fit at peak is checked
+    pCursor1D->Enable(! pStartFitAtPeak->IsChecked() ); 
+
+}
+
+
 void wxStfCursorsDlg::OnPageChanged(wxNotebookEvent& event) {
     event.Skip();
     if (actDoc!=NULL) {
@@ -1639,6 +2139,8 @@ void wxStfCursorsDlg::UpdateCursors() {
         iNewValue1=(int)actDoc->GetMeasCursor();
         cursor1isTime=cursorMIsTime;
         pText1=(wxTextCtrl*)FindWindow(wxTEXTM);
+        // update Show ruler
+        SetRuler( actDoc->GetMeasRuler() );
         break;
 
     case stf::peak_cursor: // Peak
@@ -1648,12 +2150,16 @@ void wxStfCursorsDlg::UpdateCursors() {
         cursor2isTime=cursor2PIsTime;
         pText1=(wxTextCtrl*)FindWindow(wxTEXT1P);
         pText2=(wxTextCtrl*)FindWindow(wxTEXT2P);
+        // Update peak at the end
+        SetPeakAtEnd( actDoc->GetPeakAtEnd() ); 
         // Update the mean peak points and direction:
         SetPeakPoints( actDoc->GetPM() );
         SetDirection( actDoc->GetDirection() );
         SetFromBase( actDoc->GetFromBase() );
         // Update rise time factor
         SetRTFactor( actDoc->GetRTFactor() );
+        // Update threshold slope
+        SetSlope( actDoc->GetSlopeForThreshold() );
         break;
 
     case stf::base_cursor: // Base
@@ -1663,6 +2169,7 @@ void wxStfCursorsDlg::UpdateCursors() {
         cursor2isTime=cursor2BIsTime;
         pText1=(wxTextCtrl*)FindWindow(wxTEXT1B);
         pText2=(wxTextCtrl*)FindWindow(wxTEXT2B);
+        SetBaselineMethod( actDoc->GetBaselineMethod() );
         break;
 
     case stf::decay_cursor: // Decay
@@ -1672,6 +2179,8 @@ void wxStfCursorsDlg::UpdateCursors() {
         cursor2isTime=cursor2DIsTime;
         pText1=(wxTextCtrl*)FindWindow(wxTEXT1D);
         pText2=(wxTextCtrl*)FindWindow(wxTEXT2D);
+        // Update left decay cursor to peak 
+        SetStartFitAtPeak( actDoc->GetStartFitAtPeak() );
         break;
 
     case stf::latency_cursor: // Latency
@@ -1739,7 +2248,7 @@ void wxStfCursorsDlg::UpdateCursors() {
         pText2->SetValue( strNewValue2 );
     }
     
-    SetSlope( actDoc->GetSlopeForThreshold() );
+    //SetSlope( actDoc->GetSlopeForThreshold() );
     
     wxString slopeUnits;
     slopeUnits += stf::std2wx( actDoc->at(actDoc->GetCurChIndex()).GetYUnits() );
@@ -1803,3 +2312,11 @@ bool wxStfCursorsDlg::GetRuler() const {
     return pMeasCursor->IsChecked();
 }
 
+void wxStfCursorsDlg::SetRuler(bool value) {
+    wxCheckBox* pMeasCursor = (wxCheckBox*)FindWindow( wxMEASCURSOR );
+    if (pMeasCursor == NULL) {
+        wxGetApp().ErrorMsg(wxT("null pointer in wxStfCursorsDlg::SetRuler()"));
+        return;
+    }
+        pMeasCursor->SetValue(value);
+}
