@@ -131,6 +131,47 @@ wxStfGraph* actGraph() {
     return pView->GetGraph();
 }
 
+bool refresh_graph() {
+    wxStfGraph* pGraph = actGraph();
+    if ( !pGraph ) {
+        ShowError( wxT("Pointer to graph is zero") );
+        return false;
+    }
+    pGraph->Refresh();
+    return true;
+}
+
+// update data and labels in the results box
+bool update_results_table(){
+    wxStfChildFrame* pFrame = (wxStfChildFrame*)actDoc()->GetDocumentWindow();
+    if (!pFrame) {
+        ShowError( wxT("Error in update_results_table()") );
+        return false;
+    }
+
+    wxGetApp().OnPeakcalcexecMsg();
+    pFrame->UpdateResults();
+    return true;
+}
+
+void write_stf_registry(const wxString& item, int value){
+    wxGetApp().wxWriteProfileInt(wxT("Settings"), item, value);
+}
+
+bool update_cursor_dialog( ) {
+    if (wxGetApp().GetCursorsDialog()!=NULL && wxGetApp().GetCursorsDialog()->IsShown()) {
+        try {
+            wxGetApp().GetCursorsDialog()->UpdateCursors();
+        }
+        catch (const std::runtime_error& e) {
+            ShowExcept( e );
+            // We don't necessarily need to return false here.
+        }
+    }
+
+    return refresh_graph();
+}
+
 bool check_doc( bool show_dialog ) {
     if (actDoc() == NULL)  {
         if (show_dialog)
@@ -150,15 +191,6 @@ std::string get_filename( ) {
 #endif    
 }
 
-bool refresh_graph() {
-    wxStfGraph* pGraph = actGraph();
-    if ( !pGraph ) {
-        ShowError( wxT("Pointer to graph is zero") );
-        return false;
-    }
-    pGraph->Refresh();
-    return true;
-}
 
 std::string get_versionstring() {
 #if (wxCHECK_VERSION(2, 9, 0) || defined(MODULE_ONLY))
@@ -727,20 +759,6 @@ double rthigh_index( bool active ) {
     }
 }
 
-bool update_cursor_dialog( ) {
-    if (wxGetApp().GetCursorsDialog()!=NULL && wxGetApp().GetCursorsDialog()->IsShown()) {
-        try {
-            wxGetApp().GetCursorsDialog()->UpdateCursors();
-        }
-        catch (const std::runtime_error& e) {
-            ShowExcept( e );
-            // We don't necessarily need to return false here.
-        }
-    }
-
-    return refresh_graph();
-}
-
 double get_threshold_time( bool is_time ) {
     if ( !check_doc() ) return -1;
 
@@ -797,18 +815,13 @@ bool set_risetime_factor(double factor) {
         return false;
     }
 
-    wxStfChildFrame* pFrame = (wxStfChildFrame*)actDoc()->GetDocumentWindow();
-    if ( !pFrame ) {
-        ShowError( wxT("Pointer to frame is zero") );
-        return false;
-    }
-
     int RTFactor = (int)(factor*100);
     actDoc()->SetRTFactor(RTFactor); // defined in wxStfApp::OnPeakcalcexecMsg
-    wxGetApp().OnPeakcalcexecMsg(); // update results table and write Stf registry
-    pFrame->UpdateResults(); // update results table and markers
- 
+    update_cursor_dialog();
+    update_results_table();
+    write_stf_registry(wxT("RTFactor"), RTFactor);
     return true;
+ 
         
 }
 bool set_fit_start( double pos, bool is_time ) {
@@ -984,6 +997,45 @@ bool set_peak_direction( const char* direction ) {
     return false;
 
 }
+const char* get_baseline_method() {
+    if ( !check_doc() ) return "";
+
+    const char *method=" ";
+    if ( actDoc()->GetBaselineMethod() == stf::mean_sd )
+        method = "mean";
+    else if ( actDoc()->GetBaselineMethod() == stf::median_iqr )
+        method = "median";
+    
+    return method;
+}
+
+bool set_baseline_method( const char* method ) {
+    if ( !check_doc() ) return false;
+
+    const wxString myitem = wxT("BaselineMethod");
+    if ( strcmp( method, "mean" ) == 0 ) {
+        actDoc()->SetBaselineMethod( stf::mean_sd );
+        update_cursor_dialog();
+        update_results_table();
+        write_stf_registry(myitem, stf::mean_sd);
+        return true;
+    }
+    else if ( strcmp( method, "median" ) == 0 ) {
+        actDoc()->SetBaselineMethod( stf::median_iqr );
+        update_cursor_dialog(); // update wxStfCursorsDlg
+        update_results_table(); // update results and labels in the table
+        write_stf_registry(myitem, stf::median_iqr); // write in .Stimfit
+        return true;
+    }
+    else {
+        wxString msg;
+        msg << wxT("\"") << wxString::FromAscii(method) << wxT("\" is not a valid method\n");
+        msg << wxT("Use \"mean\" or \"median\"");
+        ShowError( msg );
+        return false;
+    }
+}
+
 
 const char* get_latency_start_mode( ) {
     if ( !check_doc() ) return "";
@@ -1004,32 +1056,55 @@ const char* get_latency_start_mode( ) {
 bool set_latency_start_mode( const char* mode ) {
     if ( !check_doc() ) return false;
 
+    const wxString myitem = wxT("LatencyStartMode");
+    bool dlg_OK, result_OK;
     if ( strcmp( mode, "manual" ) == 0 ) {
         actDoc()->SetLatencyStartMode( stf::manualMode );
-        return update_cursor_dialog();
+        dlg_OK = update_cursor_dialog();
+        result_OK = update_results_table();
+        if (dlg_OK && result_OK) {
+            write_stf_registry(myitem, stf::manualMode);
+            return true;
+        }
+        return false;
     }
-
-    if ( strcmp( mode, "peak" ) == 0 ) {
+    else if ( strcmp( mode, "peak" ) == 0 ) {
         actDoc()->SetLatencyStartMode( stf::peakMode );
-        return update_cursor_dialog();
+        dlg_OK = update_cursor_dialog();
+        result_OK = update_results_table();
+        if (dlg_OK && result_OK) {
+            write_stf_registry(myitem, stf::peakMode);
+            return true;
+        }
+        return false;
     }
-
-    if ( strcmp( mode, "rise" ) == 0 ) {
+    else if ( strcmp( mode, "rise" ) == 0 ) {
         actDoc()->SetLatencyStartMode( stf::riseMode );
-        return update_cursor_dialog();
+        dlg_OK = update_cursor_dialog();
+        result_OK = update_results_table();
+        if (dlg_OK && result_OK) {
+            write_stf_registry(myitem, stf::riseMode);
+            return true;
+        }
+        return false;
     }
-
-    if ( strcmp( mode, "half" ) == 0 ) {
+    else if ( strcmp( mode, "half" ) == 0 ) {
         actDoc()->SetLatencyStartMode( stf::halfMode );
-        return update_cursor_dialog();
+        dlg_OK = update_cursor_dialog();
+        result_OK = update_results_table();
+        if (dlg_OK && result_OK) {
+            write_stf_registry(myitem, stf::halfMode);
+            return true;
+        }
+        return false;
+    }
+    else {
+        wxString msg;
+        msg << wxT("\"") << wxString::FromAscii(mode) << wxT("\" is not a valid start latency mode\n");
+        msg << wxT("Use \"manual\", \"peak\", \"rise\" or \"half\"");
+        ShowError( msg );
+        return false;
     }
-
-    wxString msg;
-    msg << wxT("\"") << wxString::FromAscii(mode) << wxT("\" is not a valid mode\n");
-    msg << wxT("Use \"up\", \"down\" or \"both\"");
-    ShowError( msg );
-    return false;
-
 }
 
 const char* get_latency_end_mode( ) {
@@ -1053,36 +1128,66 @@ const char* get_latency_end_mode( ) {
 bool set_latency_end_mode( const char* mode ) {
     if ( !check_doc() ) return false;
 
+    const wxString myitem = wxT("LatencyEndMode");
+    bool dlg_OK, result_OK;
+
     if ( strcmp( mode, "manual" ) == 0 ) {
         actDoc()->SetLatencyEndMode( stf::manualMode );
-        return update_cursor_dialog();
+        dlg_OK = update_cursor_dialog();
+        result_OK = update_results_table();
+        if (dlg_OK && result_OK) {
+            write_stf_registry(myitem, stf::manualMode);
+            return true;
+        }
+        return false;
     }
-
-    if ( strcmp( mode, "peak" ) == 0 ) {
+    else if ( strcmp( mode, "peak" ) == 0 ) {
         actDoc()->SetLatencyEndMode( stf::peakMode );
-        return update_cursor_dialog();
+        dlg_OK = update_cursor_dialog();
+        result_OK = update_results_table();
+        if (dlg_OK && result_OK) {
+            write_stf_registry(myitem, stf::peakMode);
+            return true;
+        }
+        return false;
     }
-
-    if ( strcmp( mode, "rise" ) == 0 ) {
+    else if ( strcmp( mode, "rise" ) == 0 ) {
         actDoc()->SetLatencyEndMode( stf::riseMode );
-        return update_cursor_dialog();
+        dlg_OK = update_cursor_dialog();
+        result_OK = update_results_table();
+        if (dlg_OK && result_OK) {
+            write_stf_registry(myitem, stf::riseMode);
+            return true;
+        }
+        return false;
     }
-
-    if ( strcmp( mode, "half" ) == 0 ) {
+    else if ( strcmp( mode, "half" ) == 0 ) {
         actDoc()->SetLatencyEndMode( stf::halfMode );
-        return update_cursor_dialog();
+        dlg_OK = update_cursor_dialog();
+        result_OK = update_results_table();
+        if (dlg_OK && result_OK) {
+            write_stf_registry(myitem, stf::halfMode);
+            return true;
+        }
+        return false;
     }
-
-    if ( strcmp( mode, "foot" ) == 0 ) {
+    else if ( strcmp( mode, "foot" ) == 0 ) {
         actDoc()->SetLatencyEndMode( stf::footMode );
-        return update_cursor_dialog();
+        dlg_OK = update_cursor_dialog();
+        result_OK = update_results_table();
+        if (dlg_OK && result_OK) {
+            write_stf_registry(myitem, stf::footMode);
+            return true;
+        }
+        return false;
+    }
+    else {
+        wxString msg;
+        msg << wxT("\"") << wxString::FromAscii(mode) << wxT("\" is not a valid end latency mode\n");
+        msg << wxT("Use \"manual\", \"peak\", \"rise\", \"half\" or \"foot\"");
+        ShowError( msg );
+        return false;
     }
-
-    wxString msg;
-    msg << wxT("\"") << wxString::FromAscii(mode) << wxT("\" is not a valid mode\n");
-    msg << wxT("Use \"up\", \"down\" or \"both\"");
-    ShowError( msg );
-    return false;
 
 }
 
